
/*
 * Copyright (c) 2021, NVIDIA CORPORATION.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <raft/distance/distance.hpp>
#include <raft/handle.hpp>
#include <rmm/device_uvector.hpp>
#include "pairwise_distance_euclidean.cuh"

namespace ML {

namespace Metrics {
void pairwise_distance_euclidean(const raft::handle_t& handle,
                                 const double* x,
                                 const double* y,
                                 double* dist,
                                 int m,
                                 int n,
                                 int k,
                                 raft::distance::DistanceType metric,
                                 bool isRowMajor,
                                 double metric_arg)
{
  // Call the distance function
  switch (metric) {
    case raft::distance::DistanceType::L2Expanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2Expanded, double, double, double, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2SqrtExpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2SqrtExpanded, double, double, double, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2Unexpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2Unexpanded, double, double, double, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2SqrtUnexpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2SqrtUnexpanded, double, double, double, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    default: THROW("Unknown or unsupported distance metric '%d'!", (int)metric);
  }
}

void pairwise_distance_euclidean(const raft::handle_t& handle,
                                 const float* x,
                                 const float* y,
                                 float* dist,
                                 int m,
                                 int n,
                                 int k,
                                 raft::distance::DistanceType metric,
                                 bool isRowMajor,
                                 float metric_arg)
{
  // Call the distance function
  switch (metric) {
    case raft::distance::DistanceType::L2Expanded:
      raft::distance::distance<raft::distance::DistanceType::L2Expanded, float, float, float, int>(
        x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2SqrtExpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2SqrtExpanded, float, float, float, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2Unexpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2Unexpanded, float, float, float, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    case raft::distance::DistanceType::L2SqrtUnexpanded:
      raft::distance::
        distance<raft::distance::DistanceType::L2SqrtUnexpanded, float, float, float, int>(
          x, y, dist, m, n, k, handle.get_stream(), isRowMajor);
      break;
    default: THROW("Unknown or unsupported distance metric '%d'!", (int)metric);
  }
}

}  // namespace Metrics
}  // namespace ML
